Triggers = {}




-- Function called only once at the beginning of each level.
function Triggers.init(restoring_game)


	-- Boolean airNotBreathable variable. Default to air is breathable. (If the level is vacuum this is fixed elsewhere.)
	airNotBreathable = false

	-- Counter for length of time not breathing.
	timeNotBreathing = 0

	-- Default oxygen level = 3600. This equates to 2 minutes of oxygen.
	oxyLevel = 3600

	-- Player not holding breath flag is false.
	isHoldingBreath = false


	-- For all players...
	for p in Players() do
	
	
	
	
		-- Initialize the player's oxygen to only 1 full breath, with an empty O2 tank.
		p.oxygen = oxyLevel
			

		-- Print this message to all player's screens.
		p:print("Realistic.lua active.")
		
		
		
		
		-- Create an a (1 x p) array, where p is the number of active players.
		-- This array will hold:
		-- Amount of oxygen for each player p.
		
		
		
		
		
		

	-- End for all players
	end



-- End function begin level.
end































-- THIS IS THE FUNCTION CALLED 30x PER SECOND DURING GAMEPLAY

-- WHAT IT DOES:
-- Manage underwater breathing
function Triggers.idle()

	
	
	
	-- For each player p in all players
	for p in Players() do
	
	
		-- If the player is dead...
		if p.dead then
		
			-- Fade the player's screen out (looks terrible)
			--p:fade_screen("long bright")
		
		
		end
		
	
		-- If the player is almost dead (Less than 10 life left)
		if p.life < 40 and not p.dead then
	
			-- F#@$ with the player's field of view for as long as this condition exists.
			p.extravision_duration = 30
		
			-- And fade the player's screen red in heartbeat rhythms
			p:fade_screen("big red")
	
		-- End player almost dead
		end
		
			
		-- If the player's head is under a liquid OR the player is on a vacuum level... (Means player is holding breath or breathing through a tank)
		if p.head_below_media or Level.vacuum and not p.dead then
		
			-- Set air not breathable boolean to true.
			airNotBreathable = true
			
			-- Increment the time not breathing counter by 1 tick.
			timeNotBreathing = timeNotBreathing + 1
			
			-- ...And if the player is running on tank oxygen (oxy level > 3600)...
			if p.oxygen > 3600 then
			
				-- Player is not holding breath
				isHoldingBreath = false
				
				-- Play "inhale" sound every 60 ticks (1 second), starting at t = 0 ticks.
				if ((timeNotBreathing % 60) == 0) then
			
					p.monster:play_sound("spht death",0.1)
			
				end
			
				-- Play "exhale" sound every 60 ticks (1 second), starting at t = 30 ticks.
				if (((timeNotBreathing % 60) - 30) == 0) then
			
					p.monster:play_sound("rocket flyby",0.1)
			
				end
			
			-- End tank oxygen case
			end
			
			-- ... But if the player is has less than or = 3600 oxygen, the player must not be breathing.
			if p.oxygen <= 3600 then
			
				-- Player must be holding breath
				isHoldingBreath = true
			
			
			end
			
			-- If the player is almost out of oxygen (Less than 10 seconds of breath left) and the player isn't dead
			if (p.oxygen < 600) and not p.dead then
			
				-- F#@$ with the player's field of view for as long as this condition exists.
				p.extravision_duration = 30
				
				-- And fade the player's screen black in heartbeat rhythms
				p:fade_screen("long cinematic fade in")
				
		
			-- End player almost suffocated
			end
			
		-- End player underwater or in vacuum
		end
		
		
		-- If the player just emerged from a liquid...
		if (not p.head_below_media) and (isHoldingBreath) then
		
			-- ...And if the player would have been holding their breath (Less than tank level oxygen)...
			if p.oxygen <= 3600 then
		
				-- ...And if the player was not breathing for longer than 300 ticks (10 seconds)...
				if (timeNotBreathing > 300) then
			
					-- Play a "gasp" sound
					p.monster:play_sound("suffocation",0.7)
			
				-- End catching breath
				end
				
			-- End holding breath	
			end	
			
			-- Player is no longer holding their breath
			isHoldingBreath = false
			
			-- Reset time not breathing counter to 0
			timeNotBreathing = 0
			
		-- End player emerging from liquid case
		end

		
		-- If the player is not under liquid, or on a vacuum level, or dead
		if (not p.head_below_media) and (not Level.vacuum) and (not p.dead) then
		
		-- Player is not holding their breath
		isHoldingBreath = false
		
			-- And if the player's oxygen is less than 3600 (had been holding their breath)
			if p.oxygen < 3600 then
			
				-- Restore the player's oxygen (as if catching their breath)
				p.oxygen = 3600
			
			end
		
		end
		
		
		-- Manage oxygen level warning
		-- If the player is breathing through the tank, and oxygen level is 3601 (basically empty)...
		if (not isHoldingBreath) and (p.oxygen == 3601) then
		
			-- Print this message
			p:print("Oxygen Tank Empty")
			
			-- Play the sound of "releasing air".
			p.monster:play_sound("heavy spht door closed",1.0)
		
			-- Player is now holding their breath.
			isHoldingBreath = true
		
		
		end
	
	
	



	
		
		
		
	-- End for all players
	end
	
-- End function called every 1/30 sec
end